@@ -411,7 +411,7 @@ def image_to_raw(image_href, path, path_tmp):
         if fmt != "raw":
             staged = "%s.converted" % path
 
-            utils.is_memory_insufficent(raise_if_fail=True)
+            utils.is_memory_insufficient(raise_if_fail=True)
             LOG.debug("%(image)s was %(format)s, converting to raw",
                       {'image': image_href, 'format': fmt})
             with fileutils.remove_path_on_error(staged):
@@ -527,8 +527,8 @@ def create_boot_iso(context, output_filename, kernel_href,
     :raises: ImageCreationFailed, if creating boot ISO failed.
     """
     with utils.tempdir() as tmpdir:
-        kernel_path = os.path.join(tmpdir, kernel_href.split('/')[-1])
-        ramdisk_path = os.path.join(tmpdir, ramdisk_href.split('/')[-1])
+        kernel_path = os.path.join(tmpdir, 'kernel')
+        ramdisk_path = os.path.join(tmpdir, 'ramdisk')
         fetch(context, kernel_href, kernel_path)
         fetch(context, ramdisk_href, ramdisk_path)
 
@@ -543,13 +543,11 @@ def create_boot_iso(context, output_filename, kernel_href,
             deploy_iso_path = esp_image_path = None
 
             if deploy_iso_href:
-                deploy_iso_path = os.path.join(
-                    tmpdir, deploy_iso_href.split('/')[-1])
+                deploy_iso_path = os.path.join(tmpdir, 'iso')
                 fetch(context, deploy_iso_href, deploy_iso_path)
 
             elif esp_image_href:
-                esp_image_path = os.path.join(
-                    tmpdir, esp_image_href.split('/')[-1])
+                esp_image_path = os.path.join(tmpdir, 'esp')
                 fetch(context, esp_image_href, esp_image_path)
 
             elif CONF.esp_image:
@@ -582,7 +580,8 @@ def is_whole_disk_image(ctx, instance_info):
     :param instance_info: a node's instance info dict
 
     :returns: True for whole disk images and False for partition images
-        and None on no image_source or Error.
+        and None on no image_source, the source being a path, or upon an
+        Error.
     """
     image_source = instance_info.get('image_source')
     if not image_source:
@@ -608,6 +607,11 @@ def is_whole_disk_image(ctx, instance_info):
                                and not iproperties.get('ramdisk_id'))
     else:
         # Non glance image ref
+        if is_source_a_path(ctx, instance_info.get('image_source')):
+            # Nothing is returned if not valid or there was an error.
+            # A third possibility is it is not a disk image, which would
+            # still be None.
+            return
         if (not instance_info.get('kernel')
             and not instance_info.get('ramdisk')):
             is_whole_disk_image = True
@@ -615,6 +619,77 @@ def is_whole_disk_image(ctx, instance_info):
     return is_whole_disk_image
 
 
+def is_source_a_path(ctx, image_source):
+    """Determine if the image source is a path.
+
+    This method determines if a supplied URL is a path.
+
+    :param ctx: an admin/process context.
+    :param image_source: The supplied image source, expected to be a
+                         URL, which can be used to attempt to determine
+                         if the source is a path.
+    :returns: True if the image_source appears to be a path as opposed
+              to an image to be downloaded. If the image source is not
+              a path, False is returned. If any error is detected,
+              None is returned.
+    """
+    if not image_source:
+        return
+    image_service = service.get_image_service(image_source,
+                                              context=ctx)
+    try:
+        res = image_service.validate_href(image_source)
+        if 'headers' in dir(res):
+            # response/result is from the HTTP check path.
+            headers = res.headers
+        else:
+            # We have no headers.
+            headers = {}
+    except exception.ImageRefIsARedirect as e:
+        # Our exception handling formats this for us in this
+        # case. \o/
+        LOG.debug(str(e))
+        # Servers redirect to a proper folder ending in a slash if
+        # not supplied originally.
+        if e.redirect_url and e.redirect_url.endswith('/'):
+            return True
+    except Exception:
+        # NOTE(TheJulia): I don't really like this pattern, *but*
+        # the wholedisk image support is similar.
+        return
+    # NOTE(TheJulia): Files should have been caught almost exclusively
+    # before with the Content-Length check.
+    # When the ISO is mounted and the webserver mount point url is
+    # checked here, it has both 'Content-Length' and 'Content-Type'
+    # due to which it always returns False. Hence switched the conditions.
+    if ('Content-Type' in headers
+            and str(headers['Content-Type']).startswith('text/html')):
+        LOG.debug('Evaluated %(url)s to determine if it is a URL to a path '
+                  'or a file. A Content-Type header was returned with a text '
+                  'content, which suggests a file list was returned.',
+                  {'url': image_source})
+        return True
+    # When issuing a head request, folders have no length
+    # A list can be generated by the server.. This is a solid
+    # hint.
+    if ('Content-Type' in headers
+            and (str(headers['Content-Type']) != 'text/html')
+            and 'Content-Length' in headers):
+        LOG.debug('Evaluated %(url)s to determine if it is a URL to a path '
+                  'or a file. A Content-Length header was returned '
+                  'suggesting file.',
+                  {'url': image_source})
+        # NOTE(TheJulia): Files on a webserver have a length which is returned
+        # when headres are queried.
+        return False
+    if image_source.endswith('/'):
+        # If all else fails, looks like a URL, and the server didn't give
+        # us any hints.
+        return True
+    # We were unable to determine if this was a folder or a file.
+    return False
+
+
 def _extract_iso(extract_iso, extract_dir):
     # NOTE(rpittau): we could probably just extract the files we need
     # if we find them. Also we probably need to detect the correct iso
