@@ -37,9 +37,9 @@ from ironic.common import states
 from ironic.conductor import allocations
 from ironic.conductor import notification_utils as notify_utils
 from ironic.conductor import task_manager
+from ironic.conductor import utils
 from ironic.conf import CONF
 from ironic.db import api as dbapi
-from ironic.drivers import base as driver_base
 from ironic.drivers.modules import deploy_utils
 from ironic import objects
 from ironic.objects import fields as obj_fields
@@ -48,27 +48,6 @@ from ironic.objects import fields as obj_fields
 LOG = log.getLogger(__name__)
 
 
-def _check_enabled_interfaces():
-    """Sanity-check enabled_*_interfaces configs.
-
-    We do this before we even bother to try to load up drivers. If we have any
-    dynamic drivers enabled, then we need interfaces enabled as well.
-
-    :raises: ConfigInvalid if an enabled interfaces config option is empty.
-    """
-    empty_confs = []
-    iface_types = ['enabled_%s_interfaces' % i
-                   for i in driver_base.ALL_INTERFACES]
-    for iface_type in iface_types:
-        conf_value = getattr(CONF, iface_type)
-        if not conf_value:
-            empty_confs.append(iface_type)
-    if empty_confs:
-        msg = (_('Configuration options %s cannot be an empty list.') %
-               ', '.join(empty_confs))
-        raise exception.ConfigInvalid(error_msg=msg)
-
-
 class BaseConductorManager(object):
 
     def __init__(self, host, topic):
@@ -86,9 +65,9 @@ class BaseConductorManager(object):
     def prepare_host(self):
         """Prepares host for initialization
 
-        Removes existing database entries involved with node locking for nodes
-        in a transitory power state and nodes that are presently locked by
-        the hostname of this conductor.
+        Prepares the conductor for basic operation by removing any existing
+        transitory node power states and reservations which were previously
+        held by this host.
 
         Under normal operation, this is also when the initial database
         connectivity is established for the conductor's normal operation.
@@ -109,10 +88,14 @@ class BaseConductorManager(object):
         # clear all locks held by this conductor before registering
         self.dbapi.clear_node_reservations_for_conductor(self.host)
 
-    def init_host(self, admin_context=None):
+    def init_host(self, admin_context=None, start_consoles=True,
+                  start_allocations=True):
         """Initialize the conductor host.
 
         :param admin_context: the admin context to pass to periodic tasks.
+        :param start_consoles: If consoles should be started in intialization.
+        :param start_allocations: If allocations should be started in
+                                  initialization.
         :raises: RuntimeError when conductor is already running.
         :raises: NoDriversLoaded when no drivers are enabled on the conductor.
         :raises: DriverNotFound if a driver is enabled that does not exist.
@@ -145,8 +128,6 @@ class BaseConductorManager(object):
             use_groups=self._use_groups())
         """Consistent hash ring which maps drivers to conductors."""
 
-        _check_enabled_interfaces()
-
         # NOTE(tenbrae): these calls may raise DriverLoadError or
         # DriverNotFound
         # NOTE(vdrok): Instantiate network and storage interface factory on
@@ -212,8 +193,9 @@ class BaseConductorManager(object):
 
         # Start consoles if it set enabled in a greenthread.
         try:
-            self._spawn_worker(self._start_consoles,
-                               ironic_context.get_admin_context())
+            if start_consoles:
+                self._spawn_worker(self._start_consoles,
+                                   ironic_context.get_admin_context())
         except exception.NoFreeConductorWorker:
             LOG.warning('Failed to start worker for restarting consoles.')
 
@@ -230,8 +212,9 @@ class BaseConductorManager(object):
 
         # Resume allocations that started before the restart.
         try:
-            self._spawn_worker(self._resume_allocations,
-                               ironic_context.get_admin_context())
+            if start_allocations:
+                self._spawn_worker(self._resume_allocations,
+                                   ironic_context.get_admin_context())
         except exception.NoFreeConductorWorker:
             LOG.warning('Failed to start worker for resuming allocations.')
 
@@ -536,7 +519,10 @@ class BaseConductorManager(object):
                                            err_handler=err_handler,
                                            target_state=target_state)
                     else:
-                        task.node.last_error = last_error
+                        utils.node_history_record(
+                            task.node, event=last_error,
+                            error=True,
+                            event_type=states.TRANSITION)
                         task.process_event('fail', target_state=target_state)
             except exception.NoFreeConductorWorker:
                 break
@@ -559,6 +545,7 @@ class BaseConductorManager(object):
             try:
                 with task_manager.acquire(context, node_uuid, shared=False,
                                           purpose='start console') as task:
+
                     notify_utils.emit_console_notification(
                         task, 'console_restore',
                         obj_fields.NotificationStatus.START)
@@ -580,7 +567,9 @@ class BaseConductorManager(object):
                         LOG.error(msg)
                         # If starting console failed, set node console_enabled
                         # back to False and set node's last error.
-                        task.node.last_error = msg
+                        utils.node_history_record(task.node, event=msg,
+                                                  error=True,
+                                                  event_type=states.STARTFAIL)
                         task.node.console_enabled = False
                         task.node.save()
                         notify_utils.emit_console_notification(
