@@ -31,14 +31,6 @@ scci = importutils.try_import('scciclient.irmc.scci')
 elcm = importutils.try_import('scciclient.irmc.elcm')
 
 LOG = logging.getLogger(__name__)
-
-
-# List of xxx_interface & implementation pair which uses SNMP internally
-# and iRMC driver supports
-INTERFACE_IMPL_LIST_WITH_SNMP = {
-    'inspect_interface': {'irmc', },
-    'power_interface': {'irmc', }}
-
 REQUIRED_PROPERTIES = {
     'irmc_address': _("IP address or hostname of the iRMC. Required."),
     'irmc_username': _("Username for the iRMC with administrator privileges. "
@@ -91,7 +83,9 @@ SNMP_V3_REQUIRED_PROPERTIES = {
 SNMP_V3_OPTIONAL_PROPERTIES = {
     'irmc_snmp_auth_proto': _("SNMPv3 message authentication protocol ID. "
                               "Required for version 'v3'. "
-                              "'sha' is supported."),
+                              "If using iRMC S4/S5, only 'sha' is supported."
+                              "If using iRMC S6, the valid options are "
+                              "'sha256', 'sha384', 'sha512'."),
     'irmc_snmp_priv_proto': _("SNMPv3 message privacy (encryption) protocol "
                               "ID. Required for version 'v3'. "
                               "'aes' is supported."),
@@ -220,12 +214,6 @@ def _parse_snmp_driver_info(node, info):
                       "v2c": snmp.SNMP_V2C,
                       "v3": snmp.SNMP_V3}
 
-    for int_name, impl_list in INTERFACE_IMPL_LIST_WITH_SNMP.items():
-        if getattr(node, int_name) in impl_list:
-            break
-    else:
-        return snmp_info
-
     if snmp_info['irmc_snmp_version'].lower() not in valid_versions:
         raise exception.InvalidParameterValue(_(
             "Value '%s' is not supported for 'irmc_snmp_version'.") %
@@ -257,7 +245,8 @@ def _parse_snmp_driver_info(node, info):
 def _parse_snmp_v3_info(node, info):
     snmp_info = {}
     missing_info = []
-    valid_values = {'irmc_snmp_auth_proto': ['sha'],
+    valid_values = {'irmc_snmp_auth_proto': ['sha', 'sha256', 'sha384',
+                                             'sha512'],
                     'irmc_snmp_priv_proto': ['aes']}
     valid_protocols = {'irmc_snmp_auth_proto': snmp.snmp_auth_protocols,
                        'irmc_snmp_priv_proto': snmp.snmp_priv_protocols}
