@@ -189,8 +189,7 @@ class RedfishInspect(base.InspectInterface):
     def _create_ports(self, task, system):
         enabled_macs = redfish_utils.get_enabled_macs(task, system)
         if enabled_macs:
-            inspect_utils.create_ports_if_not_exist(
-                task, enabled_macs, get_mac_address=lambda x: x[0])
+            inspect_utils.create_ports_if_not_exist(task, list(enabled_macs))
         else:
             LOG.warning("Not attempting to create any port as no NICs "
                         "were discovered in 'enabled' state for node "
